@@ -7,12 +7,14 @@ by the converter mechanism has a __asdf_traverse__() method, then it will
 call that method expecting a dict or list to be returned. The method can
 return what it thinks is suitable for display.
 """
+import re
+
 import numpy as np
 
-from .util import is_primitive
-from .treeutil import get_children
+from .schema import load_schema
 from .tags.core.ndarray import NDArrayType
-
+from .treeutil import get_children
+from .util import is_primitive
 
 __all__ = [
     "DEFAULT_MAX_ROWS",
@@ -29,18 +31,32 @@ DEFAULT_MAX_ROWS = 24
 DEFAULT_MAX_COLS = 120
 DEFAULT_SHOW_VALUES = True
 
+EXTENSION_MANAGER = None
 
-def render_tree(node, max_rows=DEFAULT_MAX_ROWS, max_cols=DEFAULT_MAX_COLS, show_values=DEFAULT_SHOW_VALUES, filters=[], identifier="root"):
+
+def render_tree(
+    node,
+    max_rows=DEFAULT_MAX_ROWS,
+    max_cols=DEFAULT_MAX_COLS,
+    show_values=DEFAULT_SHOW_VALUES,
+    filters=[],
+    identifier="root",
+    refresh_extension_manager=False,
+):
     """
     Render a tree as text with indents showing depth.
     """
-    info = _NodeInfo.from_root_node(identifier, node)
+    info = _NodeInfo.from_root_node(identifier, node, refresh_extension_manager=refresh_extension_manager)
 
     if len(filters) > 0:
         if not _filter_tree(info, filters):
             return []
 
-    renderer = _TreeRenderer(max_rows, max_cols, show_values)
+    renderer = _TreeRenderer(
+        max_rows,
+        max_cols,
+        show_values,
+    )
     return renderer.render(info)
 
 
@@ -69,17 +85,39 @@ def _format_code(value, code):
     return "\x1B[{}m{}\x1B[0m".format(code, value)
 
 
+def _get_schema_for_property(schema, attr):
+    subschema = schema.get("properties", {}).get(attr, None)
+    if subschema is not None:
+        return subschema
+    subschema = schema.get("properties", {}).get("patternProperties", None)
+    if subschema:
+        for key in subschema:
+            if re.search(key, attr):
+                return subschema[key]
+    return {}
+
+
 class _NodeInfo:
     """
     Container for a node, its state of visibility, and values used to display it.
     """
+
     @classmethod
-    def from_root_node(cls, root_identifier, root_node):
+    def from_root_node(cls, root_identifier, root_node, schema=None, refresh_extension_manager=False):
         """
         Build a _NodeInfo tree from the given ASDF root node.
         Intentionally processes the tree in breadth-first order so that recursively
         referenced nodes are displayed at their shallowest reference point.
         """
+        from .asdf import AsdfFile, get_config
+        from .extension import ExtensionManager
+
+        af = AsdfFile()
+        if refresh_extension_manager:
+            config = get_config()
+            af._extension_manager = ExtensionManager(config.extensions)
+        extmgr = af.extension_manager
+
         current_nodes = [(None, root_identifier, root_node)]
         seen = set()
         root_info = None
@@ -88,9 +126,7 @@ class _NodeInfo:
             next_nodes = []
 
             for parent, identifier, node in current_nodes:
-                if (isinstance(node, dict) or
-                    isinstance(node, tuple) or
-                    cls.supports_info(node)) and id(node) in seen:
+                if (isinstance(node, dict) or isinstance(node, tuple) or cls.supports_info(node)) and id(node) in seen:
                     info = _NodeInfo(parent, identifier, node, current_depth, recursive=True)
                     parent.children.append(info)
                 else:
@@ -98,14 +134,29 @@ class _NodeInfo:
                     if root_info is None:
                         root_info = info
                     if parent is not None:
+                        if parent.schema is not None and not cls.supports_info(node):
+                            # Extract subschema if it exists
+                            subschema = _get_schema_for_property(parent.schema, identifier)
+                            info.schema = subschema
+                            info.title = subschema.get("title", None)
                         parent.children.append(info)
                     seen.add(id(node))
                     if cls.supports_info(node):
                         tnode = node.__asdf_traverse__()
+                        # Look for a title for the attribute if it is a tagged object
+                        tag = node._tag
+                        tagdef = extmgr.get_tag_definition(tag)
+                        schema_uri = tagdef.schema_uris[0]
+                        schema = load_schema(schema_uri)
+                        info.schema = schema
+                        info.title = schema.get("title", None)
                     else:
                         tnode = node
+                    if parent is None:
+                        info.schema = schema
                     for child_identifier, child_node in get_children(tnode):
                         next_nodes.append((info, child_identifier, child_node))
+                        # extract subschema if appropriate
 
             if len(next_nodes) == 0:
                 break
@@ -115,8 +166,7 @@ class _NodeInfo:
 
         return root_info
 
-    def __init__(
-        self, parent, identifier, node, depth, recursive=False, visible=True):
+    def __init__(self, parent, identifier, node, depth, recursive=False, visible=True):
         self.parent = parent
         self.identifier = identifier
         self.node = node
@@ -124,6 +174,8 @@ class _NodeInfo:
         self.recursive = recursive
         self.visible = visible
         self.children = []
+        self.title = None
+        self.schema = None
 
     @classmethod
     def supports_info(cls, node):
@@ -164,6 +216,7 @@ class _TreeRenderer:
     """
     Render a _NodeInfo tree with indent showing depth.
     """
+
     def __init__(self, max_rows, max_cols, show_values):
         self._max_rows = max_rows
         self._max_cols = max_cols
@@ -213,9 +266,9 @@ class _TreeRenderer:
                     rows_left -= len(info.children)
                     next_infos.extend(info.children)
                 elif rows_left > 1:
-                    for child in info.children[rows_left-1:]:
+                    for child in info.children[rows_left - 1 :]:
                         child.visible = False
-                    next_infos.extend(info.children[0:rows_left-1])
+                    next_infos.extend(info.children[0 : rows_left - 1])
                     rows_left = 0
                 else:
                     for child in info.children:
@@ -243,9 +296,9 @@ class _TreeRenderer:
                     if rows_left is None or rows_left >= len(info.children):
                         next_infos.extend(info.children)
                     elif rows_left > 1:
-                        for child in info.children[rows_left-1:]:
+                        for child in info.children[rows_left - 1 :]:
                             child.visible = False
-                        next_infos.extend(info.children[0:rows_left-1])
+                        next_infos.extend(info.children[0 : rows_left - 1])
                     else:
                         for child in info.children:
                             child.visible = False
@@ -261,6 +314,12 @@ class _TreeRenderer:
     def _render(self, info, active_depths, is_tail):
         """
         Render the tree.  Called recursively on child nodes.
+
+        is_tail indicates if the child is the last of the children,
+        needed to indicate the proper connecting character in the tree
+        display. Likewise, active_depths is used to track which preceeding
+        depths are incomplete thus need continuing lines preceding in
+        the tree display.
         """
         lines = []
 
@@ -287,10 +346,8 @@ class _TreeRenderer:
         if num_visible_children > 0 and num_visible_children != len(info.children):
             hidden_count = len(info.children) - num_visible_children
             prefix = self._make_prefix(info.depth + 1, active_depths, True)
-            message = format_faint(format_italic(str(hidden_count) + ' not shown'))
-            lines.append(
-                "{}{}".format(prefix, message)
-            )
+            message = format_faint(format_italic(str(hidden_count) + " not shown"))
+            lines.append("{}{}".format(prefix, message))
 
         return lines, elided
 
@@ -303,6 +360,8 @@ class _TreeRenderer:
         else:
             line = "{}{} {}".format(prefix, format_bold(info.identifier), value)
 
+        if info.title is not None:
+            line = line + format_faint(format_italic(" # " + info.title))
         visible_children = info.visible_children
         if len(visible_children) == 0 and len(info.children) > 0:
             line = line + format_italic(" ...")
