@@ -3,34 +3,39 @@ Defragment command.
 """
 
 import asdf
-from .main import Command
+
 from .. import AsdfFile
+from .main import Command
 
-
-__all__ = ['defragment']
+__all__ = ["defragment"]
 
 
 class Defragment(Command):
     @classmethod
     def setup_arguments(cls, subparsers):
         parser = subparsers.add_parser(
-            str("defragment"), help="Defragment an ASDF file..",
-            description="""Removes any unused blocks and unused space.""")
+            str("defragment"),
+            help="Defragment an ASDF file..",
+            description="""Removes any unused blocks and unused space.""",
+        )
 
+        parser.add_argument("filename", nargs=1, help="""The ASDF file to collect.""")
+        parser.add_argument("--output", "-o", type=str, nargs="?", help="""The name of the output file.""")
         parser.add_argument(
-            'filename', nargs=1,
-            help="""The ASDF file to collect.""")
-        parser.add_argument(
-            "--output", "-o", type=str, nargs="?",
-            help="""The name of the output file.""")
-        parser.add_argument(
-            "--resolve-references", "-r", action="store_true",
+            "--resolve-references",
+            "-r",
+            action="store_true",
             help="""Resolve all references and store them directly in
-            the output file.""")
+            the output file.""",
+        )
         parser.add_argument(
-            "--compress", "-c", type=str, nargs="?",
-            choices=['zlib', 'bzp2', 'lz4'],
-            help="""Compress blocks using one of "zlib", "bzp2" or "lz4".""")
+            "--compress",
+            "-c",
+            type=str,
+            nargs="?",
+            choices=["zlib", "bzp2", "lz4"],
+            help="""Compress blocks using one of "zlib", "bzp2" or "lz4".""",
+        )
 
         parser.set_defaults(func=cls.run)
 
@@ -38,8 +43,7 @@ class Defragment(Command):
 
     @classmethod
     def run(cls, args):
-        return defragment(args.filename[0], args.output,
-                          args.resolve_references, args.compress)
+        return defragment(args.filename[0], args.output, args.resolve_references, args.compress)
 
 
 def defragment(input, output=None, resolve_references=False, compress=None):
@@ -64,7 +68,4 @@ def defragment(input, output=None, resolve_references=False, compress=None):
         ff2 = AsdfFile(ff)
         if resolve_references:
             ff2.resolve_references()
-        ff2.write_to(
-            output,
-            all_array_storage='internal',
-            all_array_compression=compress)
+        ff2.write_to(output, all_array_storage="internal", all_array_compression=compress)
