@@ -2,21 +2,17 @@ import io
 import os
 
 import numpy as np
+import pytest
 from numpy.testing import assert_array_equal
 
-import pytest
-
 import asdf
-from asdf import generic_io
-from asdf import stream
+from asdf import generic_io, stream
 
 
 def test_stream():
     buff = io.BytesIO()
 
-    tree = {
-        'stream': stream.Stream([6, 2], np.float64)
-    }
+    tree = {"stream": stream.Stream([6, 2], np.float64)}
 
     ff = asdf.AsdfFile(tree)
     ff.write_to(buff)
@@ -27,8 +23,8 @@ def test_stream():
 
     with asdf.open(buff) as ff:
         assert len(ff.blocks) == 1
-        assert ff.tree['stream'].shape == (100, 6, 2)
-        for i, row in enumerate(ff.tree['stream']):
+        assert ff.tree["stream"].shape == (100, 6, 2)
+        for i, row in enumerate(ff.tree["stream"]):
             assert np.all(row == i)
 
 
@@ -37,9 +33,7 @@ def test_stream_write_nothing():
 
     buff = io.BytesIO()
 
-    tree = {
-        'stream': stream.Stream([6, 2], np.float64)
-    }
+    tree = {"stream": stream.Stream([6, 2], np.float64)}
 
     ff = asdf.AsdfFile(tree)
     ff.write_to(buff)
@@ -48,7 +42,7 @@ def test_stream_write_nothing():
 
     with asdf.open(buff) as ff:
         assert len(ff.blocks) == 1
-        assert ff.tree['stream'].shape == (0, 6, 2)
+        assert ff.tree["stream"].shape == (0, 6, 2)
 
 
 def test_stream_twice():
@@ -56,10 +50,7 @@ def test_stream_twice():
 
     buff = io.BytesIO()
 
-    tree = {
-        'stream': stream.Stream([6, 2], np.uint8),
-        'stream2': stream.Stream([12, 2], np.uint8)
-    }
+    tree = {"stream": stream.Stream([6, 2], np.uint8), "stream2": stream.Stream([12, 2], np.uint8)}
 
     ff = asdf.AsdfFile(tree)
     ff.write_to(buff)
@@ -70,22 +61,19 @@ def test_stream_twice():
 
     ff = asdf.open(buff)
     assert len(ff.blocks) == 1
-    assert ff.tree['stream'].shape == (100, 6, 2)
-    assert ff.tree['stream2'].shape == (50, 12, 2)
+    assert ff.tree["stream"].shape == (100, 6, 2)
+    assert ff.tree["stream2"].shape == (50, 12, 2)
 
 
 def test_stream_with_nonstream():
     buff = io.BytesIO()
 
-    tree = {
-        'nonstream': np.array([1, 2, 3, 4], np.int64),
-        'stream': stream.Stream([6, 2], np.float64)
-    }
+    tree = {"nonstream": np.array([1, 2, 3, 4], np.int64), "stream": stream.Stream([6, 2], np.float64)}
 
     ff = asdf.AsdfFile(tree)
     # Since we're testing with small arrays, force this array to be stored in
     # an internal block rather than letting it be automatically put inline.
-    ff.set_array_storage(ff['nonstream'], 'internal')
+    ff.set_array_storage(ff["nonstream"], "internal")
     ff.write_to(buff)
     for i in range(100):
         buff.write(np.array([i] * 12, np.float64).tobytes())
@@ -94,45 +82,39 @@ def test_stream_with_nonstream():
 
     with asdf.open(buff) as ff:
         assert len(ff.blocks) == 1
-        assert_array_equal(ff.tree['nonstream'], np.array([1, 2, 3, 4], np.int64))
-        assert ff.tree['stream'].shape == (100, 6, 2)
+        assert_array_equal(ff.tree["nonstream"], np.array([1, 2, 3, 4], np.int64))
+        assert ff.tree["stream"].shape == (100, 6, 2)
         assert len(ff.blocks) == 2
-        for i, row in enumerate(ff.tree['stream']):
+        for i, row in enumerate(ff.tree["stream"]):
             assert np.all(row == i)
 
 
 def test_stream_real_file(tmpdir):
-    path = os.path.join(str(tmpdir), 'test.asdf')
+    path = os.path.join(str(tmpdir), "test.asdf")
 
-    tree = {
-        'nonstream': np.array([1, 2, 3, 4], np.int64),
-        'stream': stream.Stream([6, 2], np.float64)
-    }
+    tree = {"nonstream": np.array([1, 2, 3, 4], np.int64), "stream": stream.Stream([6, 2], np.float64)}
 
-    with open(path, 'wb') as fd:
+    with open(path, "wb") as fd:
         ff = asdf.AsdfFile(tree)
         # Since we're testing with small arrays, force this array to be stored
         # in an internal block rather than letting it be automatically put
         # inline.
-        ff.set_array_storage(ff['nonstream'], 'internal')
+        ff.set_array_storage(ff["nonstream"], "internal")
         ff.write_to(fd)
         for i in range(100):
             fd.write(np.array([i] * 12, np.float64).tobytes())
 
     with asdf.open(path) as ff:
         assert len(ff.blocks) == 1
-        assert_array_equal(ff.tree['nonstream'], np.array([1, 2, 3, 4], np.int64))
-        assert ff.tree['stream'].shape == (100, 6, 2)
+        assert_array_equal(ff.tree["nonstream"], np.array([1, 2, 3, 4], np.int64))
+        assert ff.tree["stream"].shape == (100, 6, 2)
         assert len(ff.blocks) == 2
-        for i, row in enumerate(ff.tree['stream']):
+        for i, row in enumerate(ff.tree["stream"]):
             assert np.all(row == i)
 
 
 def test_stream_to_stream():
-    tree = {
-        'nonstream': np.array([1, 2, 3, 4], np.int64),
-        'stream': stream.Stream([6, 2], np.float64)
-    }
+    tree = {"nonstream": np.array([1, 2, 3, 4], np.int64), "stream": stream.Stream([6, 2], np.float64)}
 
     buff = io.BytesIO()
     fd = generic_io.OutputStream(buff)
@@ -144,62 +126,58 @@ def test_stream_to_stream():
 
     buff.seek(0)
 
-    with asdf.open(generic_io.InputStream(buff, 'r')) as ff:
+    with asdf.open(generic_io.InputStream(buff, "r")) as ff:
         assert len(ff.blocks) == 2
-        assert_array_equal(ff.tree['nonstream'], np.array([1, 2, 3, 4], np.int64))
-        assert ff.tree['stream'].shape == (100, 6, 2)
-        for i, row in enumerate(ff.tree['stream']):
+        assert_array_equal(ff.tree["nonstream"], np.array([1, 2, 3, 4], np.int64))
+        assert ff.tree["stream"].shape == (100, 6, 2)
+        for i, row in enumerate(ff.tree["stream"]):
             assert np.all(row == i)
 
 
 def test_array_to_stream(tmpdir):
     tree = {
-        'stream': np.array([1, 2, 3, 4], np.int64),
+        "stream": np.array([1, 2, 3, 4], np.int64),
     }
 
     buff = io.BytesIO()
     ff = asdf.AsdfFile(tree)
-    ff.set_array_storage(tree['stream'], 'streamed')
+    ff.set_array_storage(tree["stream"], "streamed")
     ff.write_to(buff)
     buff.write(np.array([5, 6, 7, 8], np.int64).tobytes())
 
     buff.seek(0)
     ff = asdf.open(generic_io.InputStream(buff))
-    assert_array_equal(ff.tree['stream'], [1, 2, 3, 4, 5, 6, 7, 8])
+    assert_array_equal(ff.tree["stream"], [1, 2, 3, 4, 5, 6, 7, 8])
     buff.seek(0)
     ff2 = asdf.AsdfFile(ff)
     ff2.write_to(buff)
     assert b"shape: ['*']" in buff.getvalue()
 
-    with open(os.path.join(str(tmpdir), 'test.asdf'), 'wb') as fd:
+    with open(os.path.join(str(tmpdir), "test.asdf"), "wb") as fd:
         ff = asdf.AsdfFile(tree)
-        ff.set_array_storage(tree['stream'], 'streamed')
+        ff.set_array_storage(tree["stream"], "streamed")
         ff.write_to(fd)
         fd.write(np.array([5, 6, 7, 8], np.int64).tobytes())
 
-    with asdf.open(os.path.join(str(tmpdir), 'test.asdf')) as ff:
-        assert_array_equal(ff.tree['stream'], [1, 2, 3, 4, 5, 6, 7, 8])
+    with asdf.open(os.path.join(str(tmpdir), "test.asdf")) as ff:
+        assert_array_equal(ff.tree["stream"], [1, 2, 3, 4, 5, 6, 7, 8])
         ff2 = asdf.AsdfFile(ff)
         ff2.write_to(buff)
         assert b"shape: ['*']" in buff.getvalue()
 
 
 def test_too_many_streams():
-    tree = {
-        'stream1': np.array([1, 2, 3, 4], np.int64),
-        'stream2': np.array([1, 2, 3, 4], np.int64)
-    }
+    tree = {"stream1": np.array([1, 2, 3, 4], np.int64), "stream2": np.array([1, 2, 3, 4], np.int64)}
 
     ff = asdf.AsdfFile(tree)
-    ff.set_array_storage(tree['stream1'], 'streamed')
+    ff.set_array_storage(tree["stream1"], "streamed")
     with pytest.raises(ValueError):
-        ff.set_array_storage(tree['stream2'], 'streamed')
+        ff.set_array_storage(tree["stream2"], "streamed")
+
 
 def test_stream_repr_and_str():
-    tree = {
-        'stream': stream.Stream([16], np.int64)
-    }
+    tree = {"stream": stream.Stream([16], np.int64)}
 
     ff = asdf.AsdfFile(tree)
-    repr(ff.tree['stream'])
-    str(ff.tree['stream'])
+    repr(ff.tree["stream"])
+    str(ff.tree["stream"])
