@@ -1,21 +1,19 @@
 import json
+import os
+import subprocess
 import urllib.request
-from packaging.version import Version
+from contextlib import contextmanager
 from itertools import groupby
 from pathlib import Path
-import subprocess
-from contextlib import contextmanager
-import os
 
 import pytest
 import pytest_remotedata
 import virtualenv
+from common import assert_file_correct, generate_file
+from packaging.version import Version
 
 import asdf
 
-from common import generate_file, assert_file_correct
-
-
 # Strange version present on pypi that doesn't parse as a Version
 BAD_VERSIONS = {"0"}
 
@@ -29,8 +27,8 @@ MIN_VERSION_NEW_FILES = Version("2.7.0")
 # files for all the ASDF Standard versions that they claim to support.
 MIN_VERSION_OLD_FILES = Version("2.3.0")
 
-GENERATE_SCRIPT_PATH = Path(__file__).parent/"generate_file.py"
-ASSERT_SCRIPT_PATH = Path(__file__).parent/"assert_file_correct.py"
+GENERATE_SCRIPT_PATH = Path(__file__).parent / "generate_file.py"
+ASSERT_SCRIPT_PATH = Path(__file__).parent / "assert_file_correct.py"
 
 
 @contextmanager
@@ -56,7 +54,8 @@ def fetch_package_versions(package_name):
     content = urllib.request.urlopen("https://pypi.org/pypi/{}/json".format(package_name)).read()
     version_strings = json.loads(content)["releases"].keys()
     return [
-        Version(v) for v in version_strings
+        Version(v)
+        for v in version_strings
         if v not in BAD_VERSIONS and (Version(v) >= MIN_VERSION_NEW_FILES or Version(v) >= MIN_VERSION_OLD_FILES)
     ]
 
@@ -83,7 +82,7 @@ def env_run(env_path, command, *args, **kwargs):
     Run a command on the context of the virtual environment at
     the specified path.
     """
-    return subprocess.run([env_path/"bin"/command] + list(args), **kwargs).returncode == 0
+    return subprocess.run([env_path / "bin" / command] + list(args), **kwargs).returncode == 0
 
 
 def env_check_output(env_path, command, *args):
@@ -91,7 +90,7 @@ def env_check_output(env_path, command, *args):
     Run a command on the context of the virtual environment at
     the specified path, and return the output.
     """
-    return subprocess.check_output([env_path/"bin"/command] + list(args)).decode("utf-8").strip()
+    return subprocess.check_output([env_path / "bin" / command] + list(args)).decode("utf-8").strip()
 
 
 def get_supported_versions(env_path):
@@ -130,9 +129,9 @@ def env_path(asdf_version, tmp_path_factory):
 
     virtualenv.cli_run([str(path)])
 
-    assert env_run(path, "pip", "install", "asdf=={}".format(asdf_version), capture_output=True), (
-        "Failed to install asdf version {}".format(asdf_version)
-    )
+    assert env_run(
+        path, "pip", "install", "asdf=={}".format(asdf_version), capture_output=True
+    ), "Failed to install asdf version {}".format(asdf_version)
 
     return path
 
@@ -156,10 +155,9 @@ def test_file_compatibility(asdf_version, env_path, tmpdir):
     # Sanity check to ensure we're not accidentally comparing
     # the current code to itself.
     installed_version = get_installed_version(env_path)
-    assert installed_version == asdf_version, (
-        "The version of asdf in the virtualenv ({}) does ".format(installed_version) +
-        "not match the version being tested ({})".format(asdf_version)
-    )
+    assert installed_version == asdf_version, "The version of asdf in the virtualenv ({}) does ".format(
+        installed_version
+    ) + "not match the version being tested ({})".format(asdf_version)
 
     # We can only test ASDF Standard versions that both library
     # versions support.
@@ -174,21 +172,23 @@ def test_file_compatibility(asdf_version, env_path, tmpdir):
         # Confirm that a file generated by the current version of the code
         # can be read by the older version of the library.
         if asdf_version >= MIN_VERSION_NEW_FILES:
-            current_file_path = Path(str(tmpdir))/"test-current.asdf"
+            current_file_path = Path(str(tmpdir)) / "test-current.asdf"
             generate_file(current_file_path, standard_version)
             assert env_run(env_path, "python3", ASSERT_SCRIPT_PATH, current_file_path, capture_output=True), (
-                "asdf library version {} failed to read an ASDF Standard {} ".format(asdf_version, standard_version) +
-                "file produced by this code"
+                "asdf library version {} failed to read an ASDF Standard {} ".format(asdf_version, standard_version)
+                + "file produced by this code"
             )
 
         # Confirm that a file generated by the older version of the library
         # can be read by the current version of the code.
         if asdf_version >= MIN_VERSION_OLD_FILES:
-            old_file_path = Path(str(tmpdir))/"test-old.asdf"
-            assert env_run(env_path, "python3", GENERATE_SCRIPT_PATH, old_file_path, str(standard_version), capture_output=True), (
-                "asdf library version {} failed to generate an ASDF Standard {} file".format(asdf_version, standard_version)
+            old_file_path = Path(str(tmpdir)) / "test-old.asdf"
+            assert env_run(
+                env_path, "python3", GENERATE_SCRIPT_PATH, old_file_path, str(standard_version), capture_output=True
+            ), "asdf library version {} failed to generate an ASDF Standard {} file".format(
+                asdf_version, standard_version
             )
             assert_file_correct(old_file_path), (
-                "asdf library version {} produced an ASDF Standard {} ".format(asdf_version, standard_version) +
-                "that this code failed to read"
+                "asdf library version {} produced an ASDF Standard {} ".format(asdf_version, standard_version)
+                + "that this code failed to read"
             )
