@@ -2,29 +2,25 @@ import io
 import os
 import pathlib
 import warnings
-
-import yaml
-import pytest
+from dataclasses import dataclass
 
 import numpy as np
+import pytest
+import yaml
 
 # Avoid all imports of asdf at this level in order to avoid circular imports
 
 
 def pytest_addoption(parser):
+    parser.addini("asdf_schema_root", "Root path indicating where schemas are stored")
+    parser.addini("asdf_schema_skip_names", "Base names of files to skip in schema tests")
     parser.addini(
-        "asdf_schema_root", "Root path indicating where schemas are stored")
+        "asdf_schema_skip_tests", "List of tests to skip, one per line, in format <schema path suffix>::<test name>"
+    )
     parser.addini(
-        "asdf_schema_skip_names", "Base names of files to skip in schema tests")
-    parser.addini(
-        "asdf_schema_skip_tests",
-        "List of tests to skip, one per line, in format <schema path suffix>::<test name>")
-    parser.addini(
-        "asdf_schema_xfail_tests",
-        "List of tests to xfail, one per line, in format <schema path suffix>::<test name>")
-    parser.addini(
-        "asdf_schema_skip_examples",
-        "Base names of schemas whose examples should not be tested")
+        "asdf_schema_xfail_tests", "List of tests to xfail, one per line, in format <schema path suffix>::<test name>"
+    )
+    parser.addini("asdf_schema_skip_examples", "Base names of schemas whose examples should not be tested")
     parser.addini(
         "asdf_schema_tests_enabled",
         "Controls whether schema tests are enabled by default",
@@ -47,19 +43,30 @@ def pytest_addoption(parser):
         "asdf_schema_ignore_version_mismatch",
         "Set to true to disable warnings when missing explicit support for a tag",
         type="bool",
-        default=True
+        default=True,
     )
-    parser.addoption('--asdf-tests', action='store_true',
-        help='Enable ASDF schema tests')
+    parser.addoption("--asdf-tests", action="store_true", help="Enable ASDF schema tests")
 
 
 class AsdfSchemaFile(pytest.File):
     @classmethod
-    def from_parent(cls, parent, *, fspath, skip_examples=False, validate_default=True,
-        ignore_unrecognized_tag=False, ignore_version_mismatch=False, skip_tests=[], xfail_tests=[], **kwargs):
+    def from_parent(
+        cls,
+        parent,
+        *,
+        fspath,
+        skip_examples=False,
+        validate_default=True,
+        ignore_unrecognized_tag=False,
+        ignore_version_mismatch=False,
+        skip_tests=[],
+        xfail_tests=[],
+        **kwargs,
+    ):
 
         # Fix for depreciation of fspath in pytest 7+
         from asdf.util import minversion
+
         if minversion("pytest", "7.0.0"):
             path = pathlib.Path(fspath)
             kwargs["path"] = path
@@ -111,14 +118,12 @@ class AsdfSchemaFile(pytest.File):
         """Returns generator for all examples in schema at given path"""
         from asdf import treeutil
 
-        with open(str(self.fspath), 'rb') as fd:
+        with open(str(self.fspath), "rb") as fd:
             schema_tree = yaml.safe_load(fd)
 
         for node in treeutil.iter_tree(schema_tree):
-            if (isinstance(node, dict) and
-                'examples' in node and
-                isinstance(node['examples'], list)):
-                for desc, example in node['examples']:
+            if isinstance(node, dict) and "examples" in node and isinstance(node["examples"], list):
+                for example in node["examples"]:
                     yield example
 
 
@@ -141,18 +146,64 @@ class AsdfSchemaItem(pytest.Item):
 
         # Make sure that each schema itself is valid.
         schema_tree = schema.load_schema(
-            self.schema_path, resolver=default_extensions.resolver,
-            resolve_references=True)
+            self.schema_path, resolver=default_extensions.resolver, resolve_references=True
+        )
         schema.check_schema(schema_tree, validate_default=self.validate_default)
 
     def reportinfo(self):
         return self.fspath, 0, ""
 
 
+@dataclass
+class SchemaExample:
+    description: str
+    example: str
+    _version: str = None
+    other: any = None
+
+    @classmethod
+    def from_schema(cls, example: list):
+        if len(example) == 1:
+            _description = ""
+            _example = example[0]
+        elif len(example) == 2:
+            _description = example[0]
+            _example = example[1]
+            _version = None
+            _other = None
+        elif len(example) > 2:
+            _description = example[0]
+            _example = example[2]
+            _version = example[1]
+            _other = example[3:] if len(example) > 3 else None
+        else:
+            raise RuntimeError("Invalid example")
+
+        return cls(_description, _example, _version, _other)
+
+    @property
+    def version(self):
+        import asdf.versioning as versioning
+
+        if self._version is None:
+            return versioning.default_version
+
+        version = self._version.lower().split("asdf-standard-")[1]
+        return versioning.AsdfVersion(version)
+
+
 class AsdfSchemaExampleItem(pytest.Item):
     @classmethod
-    def from_parent(cls, parent, schema_path, example, example_index,
-        ignore_unrecognized_tag=False, ignore_version_mismatch=False, **kwargs):
+    def from_parent(
+        cls,
+        parent,
+        schema_path,
+        example,
+        example_index,
+        ignore_unrecognized_tag=False,
+        ignore_version_mismatch=False,
+        **kwargs,
+    ):
         if hasattr(super(), "from_parent"):
             result = super().from_parent(parent, **kwargs)
         else:
@@ -160,7 +211,7 @@ class AsdfSchemaExampleItem(pytest.Item):
             result = AsdfSchemaExampleItem(name, parent, **kwargs)
 
         result.filename = str(schema_path)
-        result.example = example
+        result.example = SchemaExample.from_schema(example)
         result.ignore_unrecognized_tag = ignore_unrecognized_tag
         result.ignore_version_mismatch = ignore_version_mismatch
         return result
@@ -171,7 +222,7 @@ class AsdfSchemaExampleItem(pytest.Item):
 
         # Make sure that the examples in the schema files (and thus the
         # ASDF standard document) are valid.
-        buff = helpers.yaml_to_asdf('example: ' + self.example.strip())
+        buff = helpers.yaml_to_asdf("example: " + self.example.example.strip(), standard_version=self.example.version)
 
         ff = AsdfFile(
             uri=util.filepath_to_url(os.path.abspath(self.filename)),
@@ -180,17 +231,15 @@ class AsdfSchemaExampleItem(pytest.Item):
         )
 
         # Fake an external file
-        ff2 = AsdfFile({'data': np.empty((1024*1024*8), dtype=np.uint8)})
+        ff2 = AsdfFile({"data": np.empty((1024 * 1024 * 8), dtype=np.uint8)})
 
         ff._external_asdf_by_uri[
-            util.filepath_to_url(
-                os.path.abspath(
-                    os.path.join(
-                        os.path.dirname(self.filename), 'external.asdf')))] = ff2
+            util.filepath_to_url(os.path.abspath(os.path.join(os.path.dirname(self.filename), "external.asdf")))
+        ] = ff2
 
         # Add some dummy blocks so that the ndarray examples work
         for i in range(3):
-            b = block.Block(np.zeros((1024*1024*8), dtype=np.uint8))
+            b = block.Block(np.zeros((1024 * 1024 * 8), dtype=np.uint8))
             b._used = True
             ff.blocks.add(b)
         b._array_storage = "streamed"
@@ -200,15 +249,15 @@ class AsdfSchemaExampleItem(pytest.Item):
             with warnings.catch_warnings():
                 warnings.simplefilter("error")
 
-                ff._open_impl(ff, buff, mode='rw')
+                ff._open_impl(ff, buff, mode="rw")
         except Exception:
-            print("From file:", self.filename)
+            print(f"Example: {self.example.description}\n From file: {self.filename}")
             raise
 
         # Just test we can write it out.  A roundtrip test
         # wouldn't always yield the correct result, so those have
         # to be covered by "real" unit tests.
-        if b'external.asdf' not in buff.getvalue():
+        if b"external.asdf" not in buff.getvalue():
             buff = io.BytesIO()
             ff.write_to(buff)
 
@@ -239,27 +288,25 @@ def _parse_test_list(content):
 
 
 def pytest_collect_file(path, parent):
-    if not (parent.config.getini('asdf_schema_tests_enabled') or
-            parent.config.getoption('asdf_tests')):
+    if not (parent.config.getini("asdf_schema_tests_enabled") or parent.config.getoption("asdf_tests")):
         return
 
-    schema_roots = parent.config.getini('asdf_schema_root').split()
+    schema_roots = parent.config.getini("asdf_schema_root").split()
     if not schema_roots:
         return
 
-    skip_names = parent.config.getini('asdf_schema_skip_names')
-    skip_examples = parent.config.getini('asdf_schema_skip_examples')
-    validate_default = parent.config.getini('asdf_schema_validate_default')
-    ignore_unrecognized_tag = parent.config.getini('asdf_schema_ignore_unrecognized_tag')
-    ignore_version_mismatch = parent.config.getini('asdf_schema_ignore_version_mismatch')
+    skip_names = parent.config.getini("asdf_schema_skip_names")
+    skip_examples = parent.config.getini("asdf_schema_skip_examples")
+    validate_default = parent.config.getini("asdf_schema_validate_default")
+    ignore_unrecognized_tag = parent.config.getini("asdf_schema_ignore_unrecognized_tag")
+    ignore_version_mismatch = parent.config.getini("asdf_schema_ignore_version_mismatch")
 
-    skip_tests = _parse_test_list(parent.config.getini('asdf_schema_skip_tests'))
-    xfail_tests = _parse_test_list(parent.config.getini('asdf_schema_xfail_tests'))
+    skip_tests = _parse_test_list(parent.config.getini("asdf_schema_skip_tests"))
+    xfail_tests = _parse_test_list(parent.config.getini("asdf_schema_xfail_tests"))
 
-    schema_roots = [os.path.join(str(parent.config.rootdir), os.path.normpath(root))
-                        for root in schema_roots]
+    schema_roots = [os.path.join(str(parent.config.rootdir), os.path.normpath(root)) for root in schema_roots]
 
-    if path.ext != '.yaml':
+    if path.ext != ".yaml":
         return None
 
     for root in schema_roots:
